@@ -274,7 +274,7 @@ int test_filename(const char *input_filename, const int block_size,
 {
   ZZ_mat<ZT> A, B;
   int status = 0;
-  status |= read_matrix(A, input_filename);
+  status |= read_file(A, input_filename);
   B = A;
   status |= test_bkz<ZT>(A, block_size, float_type, flags, prec);
   status |= test_bkz_param<ZT>(B, block_size);
@@ -325,7 +325,7 @@ int main(int /*argc*/, char ** /*argv*/)
   status |= test_linear_dep();
   status |= test_filename<mpz_t>(TESTDATADIR "/tests/lattices/dim55_in", 10, FT_DEFAULT,
                                  BKZ_DEFAULT | BKZ_AUTO_ABORT);
-#ifdef FPLLL_HAVE_QD
+#ifdef FPLLL_WITH_QD
   status |= test_filename<mpz_t>(TESTDATADIR "/tests/lattices/dim55_in", 10, FT_DD,
                                  BKZ_SD_VARIANT | BKZ_AUTO_ABORT);
 #endif
